from django import forms
from django.core.validators import FileExtensionValidator
from django.utils import timezone
from material import Layout, Row

from .models import Menu

current_year = timezone.datetime.now().year
options_for_year = [(current_year, current_year), (current_year + 1, current_year + 1)]

calendar_weeks = [(cw, cw) for cw in range(1, 53)]


class MenuUploadForm(forms.ModelForm):
    calendar_week = forms.ChoiceField(choices=calendar_weeks)
    year = forms.ChoiceField(
        initial=timezone.datetime.now().year, choices=options_for_year
    )
    pdf = forms.FileField(
        validators=[FileExtensionValidator(allowed_extensions=["pdf"])],
    )

    layout = Layout(
        Row("calendar_week", "year"),
        Row("pdf")
    )

    class Meta:
        model = Menu
        fields = ("calendar_week", "year", "pdf")
